lilypondparsertools.ContextSpeccedMusic
=======================================

.. abjad-lineage:: abjad.tools.lilypondparsertools.ContextSpeccedMusic.ContextSpeccedMusic

.. autoclass:: abjad.tools.lilypondparsertools.ContextSpeccedMusic.ContextSpeccedMusic

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondparsertools.ContextSpeccedMusic.ContextSpeccedMusic.construct
      ~abjad.tools.lilypondparsertools.ContextSpeccedMusic.ContextSpeccedMusic.known_contexts
      ~abjad.tools.lilypondparsertools.ContextSpeccedMusic.ContextSpeccedMusic.__eq__
      ~abjad.tools.lilypondparsertools.ContextSpeccedMusic.ContextSpeccedMusic.__format__
      ~abjad.tools.lilypondparsertools.ContextSpeccedMusic.ContextSpeccedMusic.__ne__
      ~abjad.tools.lilypondparsertools.ContextSpeccedMusic.ContextSpeccedMusic.__repr__

Bases
-----

- :py:class:`lilypondparsertools.Music <abjad.tools.lilypondparsertools.Music.Music>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.lilypondparsertools.ContextSpeccedMusic.ContextSpeccedMusic.known_contexts
   :noindex:

Methods
-------

.. automethod:: abjad.tools.lilypondparsertools.ContextSpeccedMusic.ContextSpeccedMusic.construct
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.ContextSpeccedMusic.ContextSpeccedMusic.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ContextSpeccedMusic.ContextSpeccedMusic.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ContextSpeccedMusic.ContextSpeccedMusic.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ContextSpeccedMusic.ContextSpeccedMusic.__repr__
   :noindex:
